<?php
/**
*
* @package alphaPORTAL
* @version $Id: functions_alpha_get.php 47 2008-08-06 23:24:21Z harmlessgoat22 $
* @copyright (c) 2008 phpALPHA Group
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* @ignore
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

/**
* Gets posts
*/
function get_posts($forum_ids, $topic_ids, $limit = 0, $character_limit = 0, $first_post = false)
{
	global $auth, $db, $template, $user;
	global $phpbb_root_path, $phpEx, $cache, $config;
	$user->add_lang('viewtopic');

	$where = '';

	// List of forums you can get posts from
	if (sizeof($forum_ids) > 0)
	{
		$new_forum_ids = array();
		foreach ($forum_ids as $forum_id)
		{
			if ($auth->acl_get('f_', $forum_id))
			{
				$new_forum_ids[] = $forum_id;
			}
		}
		$where .= ' ' . $db->sql_in_set('p.forum_id', $new_forum_ids, false, true);
	}

	// List of topics you can get posts from
	if (sizeof($topic_ids) > 0)
	{
		if ($where <> '')
		{
			$where .= ' OR';
		}
		$where .= ' ' . $db->sql_in_set('p.topic_id', $topic_ids, false, true);
	}

	// List of forums the posts MUST be from...the only ones you can read.
	$auth_forum_ids = array();
	foreach ($auth->acl_getf('f_read', true) as $forum_id => $options)
	{
		$auth_forum_ids[] = $forum_id;
	}

	if ($first_post)
	{
		$sql_array = array(
			'SELECT'	=> 'p.*, u.*, t.topic_type, t.topic_last_post_id, t.topic_attachment, f.forum_name',
			'FROM'		=> array(
				FORUMS_TABLE	=> 'f',
				POSTS_TABLE		=> 'p',
				TOPICS_TABLE	=> 't',
				USERS_TABLE		=> 'u',
			),
			'WHERE'		=> 't.topic_first_post_id = p.post_id AND p.poster_id = u.user_id AND p.forum_id = f.forum_id AND ' . $db->sql_in_set('p.forum_id', $auth_forum_ids, false, true) . ' AND (' . $where . ')',
			'ORDER_BY'	=> 'p.post_time DESC',
		);
	}
	else
	{
		$sql_array = array(
			'SELECT'	=> 'p.*, u.*, t.topic_type, t.topic_last_post_id, t.topic_attachment, f.forum_name',
			'FROM'		=> array(
				FORUMS_TABLE	=> 'f',
				POSTS_TABLE		=> 'p',
				TOPICS_TABLE	=> 't',
				USERS_TABLE		=> 'u',
			),
			'WHERE'		=> 'p.poster_id = u.user_id AND t.topic_id = p.topic_id AND p.forum_id = f.forum_id AND ' . $db->sql_in_set('p.forum_id', $auth_forum_ids, false, true) . ' AND (' . $where . ')',
			'ORDER_BY'	=> 'p.post_time DESC',
		);
	}
	$sql = $db->sql_build_query('SELECT', $sql_array);
	$result = ($limit) ? $db->sql_query_limit($sql, $limit) : $db->sql_query($sql);
	$rowset = $db->sql_fetchrowset($result);

	foreach ($rowset as $row)
	{
		if ($auth->acl_get('f_read', $row['forum_id']))
		{
			$display_notice = false;
			$attach_list = $attachments = array();

			$topic_id = (int) $row['topic_id'];

			// Grab extensions
			$extensions = array();
			if ($row['topic_attachment'])
			{
				$extensions = $cache->obtain_attach_extensions($row['forum_id']);
			}

			// Does post have an attachment? If so, add it to the list
			if ($row['post_attachment'] && $config['allow_attachments'])
			{
				$attach_list[] = $row['post_id'];
		
				if ($row['post_approved'])
				{
					$has_attachments = true;
				}
			}

			// Pull attachment data
			if (sizeof($attach_list))
			{
				if ($auth->acl_get('u_download') && $auth->acl_get('f_download', $forum_id))
				{
					$sql = 'SELECT *
						FROM ' . ATTACHMENTS_TABLE . '
						WHERE ' . $db->sql_in_set('post_msg_id', $attach_list) . '
							AND in_message = 0
						ORDER BY filetime DESC, post_msg_id ASC';
					$attach_result = $db->sql_query($sql);
			
					while ($attach_row = $db->sql_fetchrow($attach_result))
					{
						$attachments[$attach_row['post_msg_id']][] = $attach_row;
					}
					$db->sql_freeresult($attach_result);
			
					// No attachments exist, but post table thinks they do so go ahead and reset post_attach flags
					if (!sizeof($attachments))
					{
						$sql = 'UPDATE ' . POSTS_TABLE . '
							SET post_attachment = 0
							WHERE ' . $db->sql_in_set('post_id', $attach_list);
						$db->sql_query($sql);
					}
					else if ($has_attachments && !$row['topic_attachment'])
					{
						// Topic has approved attachments but its flag is wrong
						$sql = 'UPDATE ' . TOPICS_TABLE . '
							SET topic_attachment = 1
							WHERE topic_id = ' . (int) $topic_id;
						$db->sql_query($sql);
			
						$row['topic_attachment'] = 1;
					}
				}
				else
				{
					$display_notice = true;
				}
			}

			//$post_count++;
			$row['post_text'] = censor_text($row['post_text']);
			$text_only_message = $row['post_text'];
			// make list items visible as such
			if ($row['bbcode_uid'])
			{
				$text_only_message = str_replace('[*:' . $row['bbcode_uid'] . ']', '&sdot;&nbsp;', $text_only_message);
				// no BBCode in text only message
				strip_bbcode($text_only_message, $row['bbcode_uid']);
			}


			if (!$character_limit || utf8_strlen($text_only_message) < ($character_limit + 3))
			{
				$message = generate_text_for_display($row['post_text'], $row['bbcode_uid'], $row['bbcode_bitfield'], (($row['enable_bbcode']) ? OPTION_FLAG_BBCODE : 0) + (($row['enable_smilies']) ? OPTION_FLAG_SMILIES : 0) + (($row['enable_magic_url']) ? OPTION_FLAG_LINKS : 0));
			}
			else
			{
				// now find context for the searched words
				$message = get_context($text_only_message, array_filter(explode('|', request_var('highlight', '')), 'strlen'), $character_limit);
				$message = bbcode_nl2br($message);
			}
			if (!empty($attachments[$row['post_id']]))
			{
				parse_attachments($forum_id, $message, $attachments[$row['post_id']], $update_count);
			}
			include_once($phpbb_root_path . 'includes/functions_display.' . $phpEx);
			$poster_id = $row['poster_id'];

			// Grab ranks
			$ranks = $cache->obtain_ranks();
			get_user_rank($row['user_rank'], $row['user_posts'], $rank['title'], $rank['image'], $rank['image_src']);

			$template->assign_block_vars('portal_row', array(
				'POST_AUTHOR_FULL'		=> get_username_string('full', $row['user_id'], $row['username'], $row['user_colour'], $row['post_username']),
				'POST_AUTHOR_COLOUR'	=> get_username_string('colour', $row['user_id'], $row['username'], $row['user_colour'], $row['post_username']),
				'POST_AUTHOR'			=> get_username_string('username', $row['user_id'], $row['username'], $row['user_colour'], $row['post_username']),
				'U_POST_AUTHOR'			=> get_username_string('profile', $row['user_id'], $row['username'], $row['user_colour'], $row['post_username']),
	
				'POST_DATE'			=> $user->format_date($row['post_time']),
				'POST_SUBJECT'		=> $row['post_subject'],
				'MESSAGE'			=> $message,
				'EDIT_REASON'		=> $row['post_edit_reason'],
				'FORUM_NAME'		=> $row['forum_name'],
	
				'MINI_POST_IMG'		=> $user->img('icon_post_target', 'POST'),//($post_unread) ? $user->img('icon_post_target_unread', 'NEW_POST') : $user->img('icon_post_target', 'POST'),
	
				'U_EDIT'			=> (!$user->data['is_registered']) ? '' : ((($user->data['user_id'] == $row['user_id'] && $auth->acl_get('f_edit', $row['forum_id']) && ($row['post_time'] > time() - ($config['edit_time'] * 60) || !$config['edit_time'])) || $auth->acl_get('m_edit', $row['forum_id'])) ? append_sid($phpbb_root_path . 'posting.' . $phpEx, 'mode=edit&amp;f=' . $row['forum_id'] . '&amp;p=' . $row['post_id']) : ''),
				'U_QUOTE'			=> ($auth->acl_get('f_reply', $row['forum_id'])) ? append_sid($phpbb_root_path . 'posting.' . $phpEx, 'mode=quote&amp;f=' . $row['forum_id'] . '&amp;p=' . $row['post_id']) : '',
				'U_INFO'			=> ($auth->acl_get('m_info', $row['forum_id'])) ? append_sid($phpbb_root_path . 'mcp.' . $phpEx, 'i=main&amp;mode=post_details&amp;f=' . $row['forum_id'] . '&amp;p=' . $row['post_id'], true, $user->session_id) : '',
				'U_DELETE'			=> (!$user->data['is_registered']) ? '' : ((($user->data['user_id'] == $row['user_id'] && $auth->acl_get('f_delete', $row['forum_id']) && $row['topic_last_post_id'] == $row['post_id'] && ($row['post_time'] > time() - ($config['edit_time'] * 60) || !$config['edit_time'])) || $auth->acl_get('m_delete', $row['forum_id'])) ? append_sid($phpbb_root_path . 'posting.' . $phpEx, 'mode=delete&amp;f=' . $row['forum_id'] . '&amp;p=' . $row['post_id']) : ''),
	
				'U_REPORT'			=> ($auth->acl_get('f_report', $row['forum_id'])) ? append_sid($phpbb_root_path . 'report.' . $phpEx, 'f=' . $row['forum_id'] . '&amp;p=' . $row['post_id']) : '',
				'U_MCP_REPORT'		=> ($auth->acl_get('m_report', $row['forum_id'])) ? append_sid($phpbb_root_path . 'mcp.' . $phpEx, 'i=reports&amp;mode=report_details&amp;f=' . $row['forum_id'] . '&amp;p=' . $row['post_id'], true, $user->session_id) : '',
				'U_MCP_APPROVE'		=> ($auth->acl_get('m_approve', $row['forum_id'])) ? append_sid($phpbb_root_path . 'mcp.' . $phpEx, 'i=queue&amp;mode=approve_details&amp;f=' . $row['forum_id'] . '&amp;p=' . $row['post_id'], true, $user->session_id) : '',
				'U_NOTES'			=> ($auth->acl_getf_global('m_')) ? append_sid($phpbb_root_path . 'mcp.' . $phpEx, 'i=notes&amp;mode=user_notes&amp;u=' . $row['user_id'], true, $user->session_id) : '',
				'U_WARN'			=> ($auth->acl_get('m_warn') && $row['user_id'] != $user->data['user_id'] && $row['user_id'] != ANONYMOUS) ? append_sid($phpbb_root_path . 'mcp.' . $phpEx, 'i=warn&amp;mode=warn_post&amp;f=' . $row['forum_id'] . '&amp;p=' . $row['post_id'], true, $user->session_id) : '',
	
				'POST_ID'			=> $row['post_id'],
				'POSTER_ID'			=> $row['user_id'],
	
				'S_HAS_ATTACHMENTS'	=> (!empty($attachments[$row['post_id']])) ? true : false,
				'S_DISPLAY_NOTICE'	=> $display_notice && $row['post_attachment'],
				'S_POST_UNAPPROVED'	=> ($row['post_approved']) ? false : true,
				'S_POST_REPORTED'	=> ($row['post_reported'] && $auth->acl_get('m_report', $row['forum_id'])) ? true : false,
				'S_POST_GLOBAL'		=> ($row['topic_type'] == POST_GLOBAL) ? true : false,
				'U_MINI_POST'		=> append_sid("{$phpbb_root_path}viewtopic.$phpEx", 'p=' . $row['post_id']) . (($row['topic_type'] == POST_GLOBAL) ? '&amp;f=' . $row['forum_id'] : '') . '#p' . $row['post_id'],
				'U_VIEW_FORUM'		=> append_sid("{$phpbb_root_path}viewforum.$phpEx", 'f=' . $row['forum_id']),
				//'U_NEXT_POST_ID'	=> ($i < $i_total && isset($rowset[$post_list[$i + 1]])) ? $rowset[$post_list[$i + 1]]['post_id'] : '',
				//'U_PREV_POST_ID'	=> $prev_post_id,
				'S_CUSTOM_FIELDS'	=> (isset($cp_row['row']) && sizeof($cp_row['row'])) ? true : false,
				'RANK_TITLE'		=> $rank['title'],
				'RANK_IMG'			=> $rank['image'],
				'RANK_IMG_SRC'		=> $rank['image_src'],
				'POSTER_JOINED'		=> $user->format_date($row['user_regdate'], false, true),
				'POSTER_POSTS'		=> $row['user_posts'],
				'POSTER_FROM'		=> ($row['user_from']) ? $row['user_from'] : '',
				'POSTER_AVATAR'		=> get_user_avatar($row['user_avatar'], $row['user_avatar_type'], $row['user_avatar_width'], $row['user_avatar_height']),
				'POSTER_WARNINGS'	=> $row['user_warnings'],
//				'POSTER_AGE'		=> $row['user_age'],
				'SIGNATURE'			=> ($row['enable_sig']) ? $row['user_sig'] : '',
//				'EDITED_MESSAGE'	=> $l_edited_by,
//				'BUMPED_MESSAGE'	=> $l_bumped_by,
//				'POST_ICON_IMG'			=> ($topic_data['enable_icons'] && !empty($row['icon_id'])) ? $icons[$row['icon_id']]['img'] : '',
//				'POST_ICON_IMG_WIDTH'	=> ($topic_data['enable_icons'] && !empty($row['icon_id'])) ? $icons[$row['icon_id']]['width'] : '',
//				'POST_ICON_IMG_HEIGHT'	=> ($topic_data['enable_icons'] && !empty($row['icon_id'])) ? $icons[$row['icon_id']]['height'] : '',
//				'ICQ_STATUS_IMG'		=> $row['icq_status_img'],
//				'ONLINE_IMG'			=> ($poster_id == ANONYMOUS || !$config['load_onlinetrack']) ? '' : (($user_cache[$poster_id]['online']) ? $user->img('icon_user_online', 'ONLINE') : $user->img('icon_user_offline', 'OFFLINE')),
//				'S_ONLINE'				=> ($poster_id == ANONYMOUS || !$config['load_onlinetrack']) ? false : (($user_cache[$poster_id]['online']) ? true : false),
				'U_PROFILE'			=> append_sid($phpbb_root_path . 'memberlist.' . $phpEx, 'mode=viewprofile&u=' . $row['user_id']),
//				'U_SEARCH'			=> $user_cache[$poster_id]['search'],
				'U_PM'				=> ($config['allow_privmsg'] && $auth->acl_get('u_sendpm') && ($row['user_allow_pm'] || $auth->acl_gets('a_', 'm_') || $auth->acl_getf_global('m_'))) ? append_sid("{$phpbb_root_path}ucp.$phpEx", 'i=pm&amp;mode=compose&amp;u=' . $row['user_id']) : '',
				'U_EMAIL'			=> ($row['user_allow_viewemail']) ? (($config['board_email_form'] && $config['email_enable']) ? append_sid("{$phpbb_root_path}memberlist.$phpEx", "mode=email&amp;u=$poster_id") : ((($config['board_hide_emails'] && !$auth->acl_get('a_email')) ? '' : 'mailto:' . $row['user_email']))) : '',
				'U_WWW'				=> ($row['user_website']) ? $row['user_website'] : '',
				'U_ICQ'				=> ($row['user_icq']) ? 'http://www.icq.com/people/webmsg.php?to=' . $row['user_icq'] : '',
				'U_AIM'				=> ($row['user_aim'] && $auth->acl_get('u_sendim')) ? append_sid("{$phpbb_root_path}memberlist.$phpEx", "mode=contact&amp;action=aim&amp;u=$user_id") : '',
				'U_MSN'				=> ($row['user_msnm'] && $auth->acl_get('u_sendim')) ? append_sid("{$phpbb_root_path}memberlist.$phpEx", "mode=contact&amp;action=msnm&amp;u=$user_id") : '',
				'U_YIM'				=> ($row['user_yim']) ? 'http://edit.yahoo.com/config/send_webmesg?.target=' . urlencode($row['user_yim']) . '&amp;.src=pg' : '',
				'U_JABBER'			=> ($row['user_jabber'] && $auth->acl_get('u_sendim')) ? append_sid("{$phpbb_root_path}memberlist.$phpEx", "mode=contact&amp;action=jabber&amp;u=$user_id") : '',
//				'S_UNREAD_POST'		=> $post_unread,
//				'S_FIRST_UNREAD'	=> $s_first_unread,
				//'S_TOPIC_POSTER'	=> ($topic_data['topic_poster'] == $row['user_id']) ? true : false,
			));

			// Display not already displayed Attachments for this post, we already parsed them. ;)
			if (!empty($attachments[$row['post_id']]))
			{
				foreach ($attachments[$row['post_id']] as $attachment)
				{
					$template->assign_block_vars('portal_row.attachment', array(
						'DISPLAY_ATTACHMENT'	=> $attachment)
					);
				}
			}
			unset($attachments[$row['post_id']]);
		}
	}

	/* $rest = substr("abcdef", [how many to limit it]);*/
}

/**
* Gets blog posts
*/
function get_blogs($id = 0, $mode = '', $limit = 0)
{
	global $template, $db, $user, $auth, $phpbb_root_path, $phpEx, $config;
	if ($mode == 'user')
	{
		$user_id = $id;

		// Get blogs by user_id
		$sql_ary = array(
			'SELECT'	=> 'b.*, u.*',
			'FROM'		=> array(
				ALPHA_BLOG_POSTS_TABLE			=> 'b',
				USERS_TABLE						=> 'u',
			),
			'WHERE'		=> 'b.poster_id = u.user_id
				AND u.user_id = ' . $user_id,
			'ORDER_BY'	=> 'post_time DESC',
		);
		$sql = $db->sql_build_query('SELECT', $sql_ary);
		$result = ($limit) ? $db->sql_query_limit($sql, $limit) : $db->sql_query($sql);
		while ($row = $db->sql_fetchrow($result))
		{
			$content = generate_text_for_display($row['content'], $row['bbcode_uid'], $row['bbcode_bitfield'], $row['bbcode_options']);
			$template->assign_block_vars('blog_row', array(
				'POST_SUBJECT'	 		=> censor_text($row['subject']),
				'MESSAGE'	 			=> censor_text($content),
				'POST_AUTHOR_FULL'		=> get_username_string('full', $row['poster_id'], $row['username'], $row['user_colour'], $row['username']),
				'POST_AUTHOR_COLOUR'	=> get_username_string('colour', $row['poster_id'], $row['username'], $row['user_colour'], $row['username']),
				'POST_AUTHOR'			=> get_username_string('username', $row['poster_id'], $row['username'], $row['user_colour'], $row['username']),
				'U_POST_AUTHOR'			=> get_username_string('profile', $row['poster_id'], $row['username'], $row['user_colour'], $row['username']),
				'U_POST'				=> append_sid("{$phpbb_root_path}blog.$phpEx", 'b=' . $row['blog_id']),
	
				'AUTHOR_AVATAR'			=> get_user_avatar($row['user_avatar'], $row['user_avatar_type'], $row['user_avatar_width'], $row['user_avatar_height']),
				'AUTHOR_POSTS'			=> ($row['user_posts']) ? $row['user_posts'] : '',
				'AUTHOR_BLOGS'			=> ($row['user_blogs']) ? $row['user_blogs'] : '',
				'AUTHOR_JOINED'			=> $user->format_date($row['user_regdate'], false, true),
				'AUTHOR_FROM'			=> ($row['user_from']) ? $row['user_from'] : '',
				'POST_TIME'				=> $user->format_date($row['post_time'], false, true),
				'U_EDIT'				=> (($auth->acl_get('u_alpha_blog_edit') && $user->data['user_id'] == $row['poster_id']) || $auth->acl_get('m_alpha_blog_edit')) ? append_sid("{$phpbb_root_path}ucp.$phpEx", 'i=alpha_blog&mode=view_post&action=edit&b=' . $row['blog_id']) : '',
				'U_DELETE'				=> (($auth->acl_get('u_alpha_blog_delete') && $user->data['user_id'] == $row['poster_id']) || $auth->acl_get('m_alpha_blog_delete'))? append_sid("{$phpbb_root_path}ucp.$phpEx", 'i=alpha_blog&mode=view_post&action=delete&b=' . $row['blog_id']) : '',
				'U_PM'					=> ($config['allow_privmsg'] && $auth->acl_get('u_sendpm') && ($row['user_allow_pm'] || $auth->acl_gets('a_', 'm_') || $auth->acl_getf_global('m_'))) ? append_sid("{$phpbb_root_path}ucp.$phpEx", 'i=pm&amp;mode=compose&amp;u=' . $row['user_id']) : '',
				'U_EMAIL'				=> ($row['user_allow_viewemail']) ? (($config['board_email_form'] && $config['email_enable']) ? append_sid("{$phpbb_root_path}memberlist.$phpEx", "mode=email&amp;u={$row['user_id']}") : ((($config['board_hide_emails'] && !$auth->acl_get('a_email')) ? '' : 'mailto:' . $row['user_email']))) : '',
				'U_WWW'					=> ($row['user_website']) ? $row['user_website'] : '',
				'U_MSN'					=> ($row['user_msnm'] && $auth->acl_get('u_sendim')) ? append_sid("{$phpbb_root_path}memberlist.$phpEx", "mode=contact&amp;action=msnm&amp;u={$row['user_id']}") : '',
				'U_ICQ'					=> ($row['user_icq']) ? 'http://www.icq.com/people/webmsg.php?to=' . $row['user_icq'] : '',
				'U_YIM'					=> ($row['user_yim']) ? 'http://edit.yahoo.com/config/send_webmesg?.target=' . urlencode($row['user_yim']) . '&amp;.src=pg' : '',
				'U_AIM'					=> ($row['user_aim'] && $auth->acl_get('u_sendim')) ? append_sid("{$phpbb_root_path}memberlist.$phpEx", "mode=contact&amp;action=aim&amp;u={$row['user_id']}") : '',
				'U_JABBER'				=> ($row['user_jabber'] && $auth->acl_get('u_sendim')) ? append_sid("{$phpbb_root_path}memberlist.$phpEx", "mode=contact&amp;action=jabber&amp;u={$row['user_id']}") : '',
			));
			$are_labels = false;
			$sql_ary = array(
				'SELECT'	=> 'l.name, l.label_id',
				'FROM'		=> array(
					ALPHA_BLOG_POST_LABELS_TABLE	=> 'bl',
					ALPHA_BLOG_LABELS_TABLE			=> 'l',
				),
				'WHERE'		=> 'bl.blog_id = ' . $row['blog_id'] . '
					AND l.label_id = bl.label_id',
			);
			$sql = $db->sql_build_query('SELECT', $sql_ary);
			$result_lab = $db->sql_query($sql);
			while ($labels_row = $db->sql_fetchrow($result_lab))
			{
				$are_labels = true;
				$template->assign_block_vars('blog_row.label_row', array(
					'LABEL'			=> $labels_row['name'],
					'U_LABEL'		=> append_sid("{$phpbb_root_path}blog.$phpEx", 'l=' . $labels_row['label_id']),
				));
			}
			$db->sql_freeresult($result_lab);
			$template->assign_var('LABELS', $are_labels);
		}
		$db->sql_freeresult($result);
	}
	elseif ($mode == 'label')
	{
		$label_id = $id;

		// Get blogs by label_id
		$sql_ary = array(
			'SELECT'	=> 'b.*, l.name, u.*',
			'FROM'		=> array(
				ALPHA_BLOG_POSTS_TABLE			=> 'b',
				ALPHA_BLOG_POST_LABELS_TABLE	=> 'bl',
				ALPHA_BLOG_LABELS_TABLE			=> 'l',
				USERS_TABLE						=> 'u',
			),
			'WHERE'		=> 'b.blog_id = bl.blog_id
				AND l.label_id = bl.label_id
				AND l.label_id = ' . $label_id . '
				AND b.poster_id = u.user_id',
			'ORDER_BY'	=> 'post_time DESC',
		);
		$sql = $db->sql_build_query('SELECT', $sql_ary);
		$result = ($limit) ? $db->sql_query_limit($sql, $limit) : $db->sql_query($sql);
		while ($row = $db->sql_fetchrow($result))
		{
			$content = generate_text_for_display($row['content'], $row['bbcode_uid'], $row['bbcode_bitfield'], $row['bbcode_options']);
			$template->assign_block_vars('blog_row', array(
				'POST_SUBJECT'	 		=> censor_text($row['subject']),
				'MESSAGE'	 			=> censor_text($content),
				'POST_AUTHOR_FULL'		=> get_username_string('full', $row['poster_id'], $row['username'], $row['user_colour'], $row['username']),
				'POST_AUTHOR_COLOUR'	=> get_username_string('colour', $row['poster_id'], $row['username'], $row['user_colour'], $row['username']),
				'POST_AUTHOR'			=> get_username_string('username', $row['poster_id'], $row['username'], $row['user_colour'], $row['username']),
				'U_POST_AUTHOR'			=> get_username_string('profile', $row['poster_id'], $row['username'], $row['user_colour'], $row['username']),
				'U_POST'				=> append_sid("{$phpbb_root_path}blog.$phpEx", 'b=' . $row['blog_id']),
	
				'AUTHOR_AVATAR'			=> get_user_avatar($row['user_avatar'], $row['user_avatar_type'], $row['user_avatar_width'], $row['user_avatar_height']),
				'AUTHOR_POSTS'			=> ($row['user_posts']) ? $row['user_posts'] : '',
				'AUTHOR_BLOGS'			=> ($row['user_blogs']) ? $row['user_blogs'] : '',
				'AUTHOR_JOINED'			=> $user->format_date($row['user_regdate'], false, true),
				'AUTHOR_FROM'			=> ($row['user_from']) ? $row['user_from'] : '',
				'POST_TIME'				=> $user->format_date($row['post_time'], false, true),
				'U_EDIT'				=> (($auth->acl_get('u_alpha_blog_edit') && $user->data['user_id'] == $row['poster_id']) || $auth->acl_get('m_alpha_blog_edit')) ? append_sid("{$phpbb_root_path}ucp.$phpEx", 'i=alpha_blog&mode=view_post&action=edit&b=' . $row['blog_id']) : '',
				'U_DELETE'				=> (($auth->acl_get('u_alpha_blog_delete') && $user->data['user_id'] == $row['poster_id']) || $auth->acl_get('m_alpha_blog_delete'))? append_sid("{$phpbb_root_path}ucp.$phpEx", 'i=alpha_blog&mode=view_post&action=delete&b=' . $row['blog_id']) : '',
				'U_PM'					=> ($config['allow_privmsg'] && $auth->acl_get('u_sendpm') && ($row['user_allow_pm'] || $auth->acl_gets('a_', 'm_') || $auth->acl_getf_global('m_'))) ? append_sid("{$phpbb_root_path}ucp.$phpEx", 'i=pm&amp;mode=compose&amp;u=' . $row['user_id']) : '',
				'U_EMAIL'				=> ($row['user_allow_viewemail']) ? (($config['board_email_form'] && $config['email_enable']) ? append_sid("{$phpbb_root_path}memberlist.$phpEx", "mode=email&amp;u={$row['user_id']}") : ((($config['board_hide_emails'] && !$auth->acl_get('a_email')) ? '' : 'mailto:' . $row['user_email']))) : '',
				'U_WWW'					=> ($row['user_website']) ? $row['user_website'] : '',
				'U_MSN'					=> ($row['user_msnm'] && $auth->acl_get('u_sendim')) ? append_sid("{$phpbb_root_path}memberlist.$phpEx", "mode=contact&amp;action=msnm&amp;u={$row['user_id']}") : '',
				'U_ICQ'					=> ($row['user_icq']) ? 'http://www.icq.com/people/webmsg.php?to=' . $row['user_icq'] : '',
				'U_YIM'					=> ($row['user_yim']) ? 'http://edit.yahoo.com/config/send_webmesg?.target=' . urlencode($row['user_yim']) . '&amp;.src=pg' : '',
				'U_AIM'					=> ($row['user_aim'] && $auth->acl_get('u_sendim')) ? append_sid("{$phpbb_root_path}memberlist.$phpEx", "mode=contact&amp;action=aim&amp;u={$row['user_id']}") : '',
				'U_JABBER'				=> ($row['user_jabber'] && $auth->acl_get('u_sendim')) ? append_sid("{$phpbb_root_path}memberlist.$phpEx", "mode=contact&amp;action=jabber&amp;u={$row['user_id']}") : '',
			));
			$are_labels = false;
			$sql_ary = array(
				'SELECT'	=> 'l.name, l.label_id',
				'FROM'		=> array(
					ALPHA_BLOG_POST_LABELS_TABLE	=> 'bl',
					ALPHA_BLOG_LABELS_TABLE			=> 'l',
				),
				'WHERE'		=> 'bl.blog_id = ' . $row['blog_id'] . '
					AND l.label_id = bl.label_id',
			);
			$sql = $db->sql_build_query('SELECT', $sql_ary);
			$result_lab = $db->sql_query($sql);
			while ($labels_row = $db->sql_fetchrow($result_lab))
			{
				$are_labels = true;
				$template->assign_block_vars('blog_row.label_row', array(
					'LABEL'			=> $labels_row['name'],
					'U_LABEL'		=> append_sid("{$phpbb_root_path}blog.$phpEx", 'l=' . $labels_row['label_id']),
				));
			}
			$db->sql_freeresult($result_lab);
			$template->assign_var('LABELS', $are_labels);
		}
		$db->sql_freeresult($result);
	}
	else
	{
		// Get all blogs
		$sql_ary = array(
			'SELECT'	=> 'b.*, u.*',
			'FROM'		=> array(
				ALPHA_BLOG_POSTS_TABLE			=> 'b',
				USERS_TABLE						=> 'u',
			),
			'WHERE'		=> 'b.poster_id = u.user_id',
			'ORDER_BY'	=> 'post_time DESC',
		);
		$sql = $db->sql_build_query('SELECT', $sql_ary);
		$result = ($limit) ? $db->sql_query_limit($sql, $limit) : $db->sql_query($sql);
		while ($row = $db->sql_fetchrow($result))
		{
			$content = generate_text_for_display($row['content'], $row['bbcode_uid'], $row['bbcode_bitfield'], $row['bbcode_options']);
			$template->assign_block_vars('blog_row', array(
				'POST_SUBJECT'	 		=> censor_text($row['subject']),
				'MESSAGE'	 			=> censor_text($content),
				'POST_AUTHOR_FULL'		=> get_username_string('full', $row['poster_id'], $row['username'], $row['user_colour'], $row['username']),
				'POST_AUTHOR_COLOUR'	=> get_username_string('colour', $row['poster_id'], $row['username'], $row['user_colour'], $row['username']),
				'POST_AUTHOR'			=> get_username_string('username', $row['poster_id'], $row['username'], $row['user_colour'], $row['username']),
				'U_POST_AUTHOR'			=> get_username_string('profile', $row['poster_id'], $row['username'], $row['user_colour'], $row['username']),
				'U_POST'				=> append_sid("{$phpbb_root_path}blog.$phpEx", 'b=' . $row['blog_id']),
	
				'AUTHOR_AVATAR'			=> get_user_avatar($row['user_avatar'], $row['user_avatar_type'], $row['user_avatar_width'], $row['user_avatar_height']),
				'AUTHOR_POSTS'			=> ($row['user_posts']) ? $row['user_posts'] : '',
				'AUTHOR_BLOGS'			=> ($row['user_blogs']) ? $row['user_blogs'] : '',
				'AUTHOR_JOINED'			=> $user->format_date($row['user_regdate'], false, true),
				'AUTHOR_FROM'			=> ($row['user_from']) ? $row['user_from'] : '',
				'POST_TIME'				=> $user->format_date($row['post_time'], false, true),
				'U_EDIT'				=> (($auth->acl_get('u_alpha_blog_edit') && $user->data['user_id'] == $row['poster_id']) || $auth->acl_get('m_alpha_blog_edit')) ? append_sid("{$phpbb_root_path}ucp.$phpEx", 'i=alpha_blog&mode=view_post&action=edit&b=' . $row['blog_id']) : '',
				'U_DELETE'				=> (($auth->acl_get('u_alpha_blog_delete') && $user->data['user_id'] == $row['poster_id']) || $auth->acl_get('m_alpha_blog_delete'))? append_sid("{$phpbb_root_path}ucp.$phpEx", 'i=alpha_blog&mode=view_post&action=delete&b=' . $row['blog_id']) : '',
				'U_PM'					=> ($config['allow_privmsg'] && $auth->acl_get('u_sendpm') && ($row['user_allow_pm'] || $auth->acl_gets('a_', 'm_') || $auth->acl_getf_global('m_'))) ? append_sid("{$phpbb_root_path}ucp.$phpEx", 'i=pm&amp;mode=compose&amp;u=' . $row['user_id']) : '',
				'U_EMAIL'				=> ($row['user_allow_viewemail']) ? (($config['board_email_form'] && $config['email_enable']) ? append_sid("{$phpbb_root_path}memberlist.$phpEx", "mode=email&amp;u={$row['user_id']}") : ((($config['board_hide_emails'] && !$auth->acl_get('a_email')) ? '' : 'mailto:' . $row['user_email']))) : '',
				'U_WWW'					=> ($row['user_website']) ? $row['user_website'] : '',
				'U_MSN'					=> ($row['user_msnm'] && $auth->acl_get('u_sendim')) ? append_sid("{$phpbb_root_path}memberlist.$phpEx", "mode=contact&amp;action=msnm&amp;u={$row['user_id']}") : '',
				'U_ICQ'					=> ($row['user_icq']) ? 'http://www.icq.com/people/webmsg.php?to=' . $row['user_icq'] : '',
				'U_YIM'					=> ($row['user_yim']) ? 'http://edit.yahoo.com/config/send_webmesg?.target=' . urlencode($row['user_yim']) . '&amp;.src=pg' : '',
				'U_AIM'					=> ($row['user_aim'] && $auth->acl_get('u_sendim')) ? append_sid("{$phpbb_root_path}memberlist.$phpEx", "mode=contact&amp;action=aim&amp;u={$row['user_id']}") : '',
				'U_JABBER'				=> ($row['user_jabber'] && $auth->acl_get('u_sendim')) ? append_sid("{$phpbb_root_path}memberlist.$phpEx", "mode=contact&amp;action=jabber&amp;u={$row['user_id']}") : '',
			));
			$are_labels = false;
			$sql_ary = array(
				'SELECT'	=> 'l.name, l.label_id',
				'FROM'		=> array(
					ALPHA_BLOG_POST_LABELS_TABLE	=> 'bl',
					ALPHA_BLOG_LABELS_TABLE			=> 'l',
				),
				'WHERE'		=> 'bl.blog_id = ' . $row['blog_id'] . '
					AND l.label_id = bl.label_id',
			);
			$sql = $db->sql_build_query('SELECT', $sql_ary);
			$result_lab = $db->sql_query($sql);
			while ($labels_row = $db->sql_fetchrow($result_lab))
			{
				$are_labels = true;
				$template->assign_block_vars('blog_row.label_row', array(
					'LABEL'			=> $labels_row['name'],
					'U_LABEL'		=> append_sid("{$phpbb_root_path}blog.$phpEx", 'l=' . $labels_row['label_id']),
				));
			}
			$db->sql_freeresult($result_lab);
			$template->assign_var('LABELS', $are_labels);
		}
		$db->sql_freeresult($result);
	}
}

?>